==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fMultianewarray.h <==
// class soot.coffi.Instruction_Multianewarray

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class d97cbc90c1eeb55e soot_coffi_Instruction__5fMultianewarray
// @dep_class d13384827121be19 soot_coffi_Instruction__5fintindex

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintindex

#include "soot/coffi/Instruction__5fintindex.h"

#ifndef _JC_soot_coffi_Instruction__5fMultianewarray_H_
#define _JC_soot_coffi_Instruction__5fMultianewarray_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fMultianewarray$sub_refs	_jc_soot_coffi_Instruction__5fMultianewarray$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fMultianewarray$sub_nonrefs	_jc_soot_coffi_Instruction__5fMultianewarray$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fMultianewarray$refs	_jc_soot_coffi_Instruction__5fMultianewarray$refs;
typedef struct _jc_soot_coffi_Instruction__5fMultianewarray$nonrefs	_jc_soot_coffi_Instruction__5fMultianewarray$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fMultianewarray$object	_jc_soot_coffi_Instruction__5fMultianewarray$object;

typedef const struct _jc_soot_coffi_Instruction__5fMultianewarray$vmethods	_jc_soot_coffi_Instruction__5fMultianewarray$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fMultianewarray$vtable	_jc_soot_coffi_Instruction__5fMultianewarray$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fMultianewarray$vtype	_jc_soot_coffi_Instruction__5fMultianewarray$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fMultianewarray$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fMultianewarray$object *);

// Virtual methods
extern jint _jc_soot_coffi_Instruction__5fMultianewarray$method$compile$7850d747d603381b(_jc_env *, struct _jc_soot_coffi_Instruction__5fMultianewarray$object *, struct _jc_byte_array *, jint);
extern jint _jc_soot_coffi_Instruction__5fMultianewarray$method$nextOffset$f8d97a51150e6758(_jc_env *, struct _jc_soot_coffi_Instruction__5fMultianewarray$object *, jint);
extern jint _jc_soot_coffi_Instruction__5fMultianewarray$method$parse$107dd9a35b0eb485(_jc_env *, struct _jc_soot_coffi_Instruction__5fMultianewarray$object *, struct _jc_byte_array *, jint);
extern struct _jc_java_lang_String$object *_jc_soot_coffi_Instruction__5fMultianewarray$method$toString$9f9bf0b6fdab502b(_jc_env *, struct _jc_soot_coffi_Instruction__5fMultianewarray$object *, struct _jc_object_array *);

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_Instruction__5fMultianewarray$method_info$compile$7850d747d603381b;
extern _jc_method _jc_soot_coffi_Instruction__5fMultianewarray$method_info$nextOffset$f8d97a51150e6758;
extern _jc_method _jc_soot_coffi_Instruction__5fMultianewarray$method_info$parse$107dd9a35b0eb485;
extern _jc_method _jc_soot_coffi_Instruction__5fMultianewarray$method_info$toString$9f9bf0b6fdab502b;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fMultianewarray$vmethods {
	jint	(*compile$7850d747d603381b)(_jc_env *, struct _jc_soot_coffi_Instruction__5fMultianewarray$object *, struct _jc_byte_array *, jint);
	jint	(*nextOffset$f8d97a51150e6758)(_jc_env *, struct _jc_soot_coffi_Instruction__5fMultianewarray$object *, jint);
	jint	(*parse$107dd9a35b0eb485)(_jc_env *, struct _jc_soot_coffi_Instruction__5fMultianewarray$object *, struct _jc_byte_array *, jint);
	struct _jc_java_lang_String$object	*(*toString$9f9bf0b6fdab502b)(_jc_env *, struct _jc_soot_coffi_Instruction__5fMultianewarray$object *, struct _jc_object_array *);
};

// Vtable
struct _jc_soot_coffi_Instruction__5fMultianewarray$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fintindex$vmethods	soot_coffi_Instruction__5fintindex;
	_jc_soot_coffi_Instruction__5fMultianewarray$vmethods	soot_coffi_Instruction__5fMultianewarray;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fMultianewarray$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fMultianewarray$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fMultianewarray$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fMultianewarray$refs {
    _jc_soot_coffi_Instruction__5fMultianewarray$sub_refs	soot_coffi_Instruction__5fMultianewarray;
    _jc_soot_coffi_Instruction__5fintindex$sub_refs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fMultianewarray$sub_nonrefs {
	jbyte	dims;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fMultianewarray$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fintindex$sub_nonrefs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction__5fMultianewarray$sub_nonrefs	soot_coffi_Instruction__5fMultianewarray;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fMultianewarray$object {
	_jc_soot_coffi_Instruction__5fMultianewarray$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fMultianewarray$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fMultianewarray$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fMultianewarray$vtype _jc_soot_coffi_Instruction__5fMultianewarray$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fMultianewarray, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fMultianewarray$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fMultianewarray_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fMultianewarray.h <==
// class soot.coffi.Instruction_Multianewarray

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class d97cbc90c1eeb55e soot_coffi_Instruction__5fMultianewarray
// @dep_class d13384827121be19 soot_coffi_Instruction__5fintindex

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintindex

#include "soot/coffi/Instruction__5fintindex.h"

#ifndef _JC_soot_coffi_Instruction__5fMultianewarray_H_
#define _JC_soot_coffi_Instruction__5fMultianewarray_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fMultianewarray$sub_refs	_jc_soot_coffi_Instruction__5fMultianewarray$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fMultianewarray$sub_nonrefs	_jc_soot_coffi_Instruction__5fMultianewarray$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fMultianewarray$refs	_jc_soot_coffi_Instruction__5fMultianewarray$refs;
typedef struct _jc_soot_coffi_Instruction__5fMultianewarray$nonrefs	_jc_soot_coffi_Instruction__5fMultianewarray$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fMultianewarray$object	_jc_soot_coffi_Instruction__5fMultianewarray$object;

typedef const struct _jc_soot_coffi_Instruction__5fMultianewarray$vmethods	_jc_soot_coffi_Instruction__5fMultianewarray$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fMultianewarray$vtable	_jc_soot_coffi_Instruction__5fMultianewarray$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fMultianewarray$vtype	_jc_soot_coffi_Instruction__5fMultianewarray$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fMultianewarray$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fMultianewarray$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_coffi_Instruction__5fMultianewarray$method$compile$7850d747d603381b(_jc_env *, struct _jc_soot_coffi_Instruction__5fMultianewarray$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
extern jint _jc_soot_coffi_Instruction__5fMultianewarray$method$nextOffset$f8d97a51150e6758(_jc_env *, struct _jc_soot_coffi_Instruction__5fMultianewarray$object *, jint) _JC_JCNI_ATTR;
extern jint _jc_soot_coffi_Instruction__5fMultianewarray$method$parse$107dd9a35b0eb485(_jc_env *, struct _jc_soot_coffi_Instruction__5fMultianewarray$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_coffi_Instruction__5fMultianewarray$method$toString$9f9bf0b6fdab502b(_jc_env *, struct _jc_soot_coffi_Instruction__5fMultianewarray$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_Instruction__5fMultianewarray$method_info$compile$7850d747d603381b;
extern _jc_method _jc_soot_coffi_Instruction__5fMultianewarray$method_info$nextOffset$f8d97a51150e6758;
extern _jc_method _jc_soot_coffi_Instruction__5fMultianewarray$method_info$parse$107dd9a35b0eb485;
extern _jc_method _jc_soot_coffi_Instruction__5fMultianewarray$method_info$toString$9f9bf0b6fdab502b;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fMultianewarray$vmethods {
	jint	(*compile$7850d747d603381b)(_jc_env *, struct _jc_soot_coffi_Instruction__5fMultianewarray$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
	jint	(*nextOffset$f8d97a51150e6758)(_jc_env *, struct _jc_soot_coffi_Instruction__5fMultianewarray$object *, jint) _JC_JCNI_ATTR;
	jint	(*parse$107dd9a35b0eb485)(_jc_env *, struct _jc_soot_coffi_Instruction__5fMultianewarray$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$9f9bf0b6fdab502b)(_jc_env *, struct _jc_soot_coffi_Instruction__5fMultianewarray$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_coffi_Instruction__5fMultianewarray$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fintindex$vmethods	soot_coffi_Instruction__5fintindex;
	_jc_soot_coffi_Instruction__5fMultianewarray$vmethods	soot_coffi_Instruction__5fMultianewarray;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fMultianewarray$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fMultianewarray$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fMultianewarray$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fMultianewarray$refs {
    _jc_soot_coffi_Instruction__5fMultianewarray$sub_refs	soot_coffi_Instruction__5fMultianewarray;
    _jc_soot_coffi_Instruction__5fintindex$sub_refs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fMultianewarray$sub_nonrefs {
	jbyte	dims;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fMultianewarray$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fintindex$sub_nonrefs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction__5fMultianewarray$sub_nonrefs	soot_coffi_Instruction__5fMultianewarray;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fMultianewarray$object {
	_jc_soot_coffi_Instruction__5fMultianewarray$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fMultianewarray$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fMultianewarray$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fMultianewarray$vtype _jc_soot_coffi_Instruction__5fMultianewarray$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fMultianewarray, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fMultianewarray$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fMultianewarray_H_ */
